%Number of steps
N=100;

%Number of Newton iterations
nNewton=1;

%End point
T=1;

%Step size
h=T/N;

%algebraic condition function handle
c= @(y) y(3)^2+y(4)^2-2*y(5)+9*y(2);
      
%root-search formulation of the implicit Euler method
F= @(y,y0) [y(1)-y0(1)-h*y(3);...
            y(2)-y0(2)-h*y(4);...
            y(3)-y0(3)+2*h*y(1)*y(5);...
            y(4)-y0(4)+2*h*y(2)*y(5)-9*h;...
            c(y)];
        
DF = @(y) [1 0 -h 0 0;
           0 1 0 -h 0;
           2*h*y(5) 0 1 0 2*h*y(1);
           0 2*h*y(5) 0 1 2*h*y(2);
           0 9 2*y(3) 2*y(4) -2];

%initial value
y=[1; 0; 0; 0; 0];

%distance to the manifold
ZB=zeros(N+1,1);
ZB(1)=c(y);

%values of the different components
X=zeros(N+1,5);
X(1,:)=y';

for ii=1:N
    
    y0=y;
    
    for jj=1:nNewton
        y=y-DF(y)\F(y,y0);
    end
    
    %values of the different components
    X(ii+1,:)=y';
    
    %distance from the manifold
    ZB(1+ii)=c(y);
end

fprintf('Maximal distance from the manifold: %e\n', max(abs(ZB)));

%Plot of the algebraic conditions evolution
t=0:h:N*h;
figure;
plot(0:h:N*h, ZB, '*-');

%Plot of the component evolution
figure;
plot(t, X(:,1), '*-',t, X(:,2), '*-',t, X(:,3), '*-',t, X(:,4), '*-',t, X(:,5), '*-');
hold on;

%Referential solution from ode23t
f = @(t,y) [y(3);...
            y(4);...
            -2*y(1)*y(5);...
            -2*y(2)*y(5)+9;...
            y(3)^2+y(4)^2-2*y(5)+9*y(2)];
J = @(t,y) [0 0 1 0 0;...
            0 0 0 1 0;...
            -2*y(5) 0 0 0 -2*y(1);...
            0 -2*y(5) 0 0 -2*y(2);...
            0 9 2*y(3) 2*y(4) -2];
M=eye(5);
M(5,5)=0;
M = @(t,y) M;
opts = odeset('Mass',M,'Jacobian',J);
y0=[1;0;0;0;0];
[t,y] = ode23t(f,[0 N*h],y0,opts);

%figure;
plot(t,y(:,1),t,y(:,2),t,y(:,3),t,y(:,4),t,y(:,5));
    