function robotodesolve
close all;

% set integration interval
tspan = [0, 2*pi];

% set initial value
y0=[0;0;0;pi/3;-pi/3];

%arm end position function
g=@(theta) sum([cos(theta)';sin(theta)'],2);

%goal path function
gamma=@(t) [4+4/5*sin(t).^3;...
     13/16*cos(t)-5/16*cos(2*t)-1/8*cos(3*t)-1/16*cos(4*t)-5/16];

% right hand side
Dc=@(theta) [-sin(theta)';cos(theta)'];

gammadot=@(t) [ 12/5*sin(t).^2*cos(t);...
        -13/16*sin(t)+5/8*sin(2*t)+3/8*sin(3*t)+1/4*sin(4*t)];

fun = @(t,y) [Dc(y)'*((Dc(y)*Dc(y)')\gammadot(t))];

%ode23
[t,y] = ode23s(fun, tspan, y0);

% compute exact path
exact_path=gamma(t');

%plot approximated and exact paths as well as
% the distance between them
approx_path=zeros(2,length(t));
err=zeros(1,length(t));
for i=1:length(t)
    approx_path(:,i)=g(y(i,1:5)');
    err(i)=norm(g(y(i,1:5)')-gamma(t(i)));
end


%Plot exact and approximated paths
figure;
plot(exact_path(1,:), exact_path(2,:),'b',approx_path(1,:),approx_path(2,:),'ro'); 
xlim([3 5]);
ylim([-1.6 0.6]);
legend('Exact path','Approximated path','Location','SouthEast');

%Plot the distance between paths
figure;
plot(t,err,'*-');
xlabel('time');
ylabel('error');
title('distance between exact and approximated path');


